"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Transformer = void 0;
const utilities_1 = require("./utilities");
class Transformer {
    constructor(storage, options) {
        this.storage = storage;
        this.options = options;
    }
    excludeProperties(value, modelName) {
        const { excludeMongooseId, excludeMongooseV } = this.options;
        if (typeof (value === null || value === void 0 ? void 0 : value.toJSON) === 'function') {
            const JSONmodel = value.toJSON();
            const excludedProperties = this.storage.getExcludeProperties(modelName);
            excludedProperties === null || excludedProperties === void 0 ? void 0 : excludedProperties.forEach((v) => {
                delete JSONmodel[v.propertyName];
            });
            if (excludeMongooseId) {
                delete JSONmodel._id;
            }
            if (excludeMongooseV) {
                delete JSONmodel.__v;
            }
            return JSONmodel;
        }
        return value;
    }
    transform(value) {
        const modelName = utilities_1.getMongooseModelName(value);
        if (modelName) {
            return this.excludeProperties(value, modelName);
        }
        if (Array.isArray(value)) {
            const newArray = [];
            value.forEach((v) => {
                newArray.push(this.transform(v));
            });
            return newArray;
        }
        if (value !== null && typeof value === 'object') {
            const newValue = {};
            Object.entries(value).forEach(([k, v]) => {
                const key = k;
                newValue[key] = this.transform(v);
            });
            return newValue;
        }
        return value;
    }
}
exports.Transformer = Transformer;
